@@ -1,3 +1,4 @@
 from .Fields import Field, Name, Username, Password, Email, Birth, Gender, PhoneNumber, Location
-from .Models import Person, UserInstance, User
+from .Models import Model, BasicModel, Instance
+from .Exceptions import CsvAndInstanceError
 from . import data
\ No newline at end of file
